<?php
$lang['textarea'] = 'Text Area';
$lang['error_calendar_incompatible'] = 'We have detected that the Calendar module is also installed..  This module is not compatible with the Calendar module and cannot co-exist with it on the same install.  Please uninstall the Calendar module';
$lang['error_event_not_found'] = 'Either event_id is not in the database, or there is more than one event with this id! (%d)';
$lang['first_page'] = '<<';
$lang['prev_page'] = '<';
$lang['next_page'] = '>';
$lang['last_page'] = '>>';
$lang['page_of'] = 'Page %d of %d';
$lang['search_results'] = 'Calendar Search Results';
$lang['search_words'] = 'Search Words';
$lang['no_results_found'] = 'No results found matching the query specified';
$lang['frequency'] = 'Frequency';
$lang['specified_date'] = 'Use the specified date';
$lang['first_sunday'] = 'First Sunday of the Month';
$lang['first_monday'] = 'First Monday of the Month';
$lang['first_tuesday'] = 'First Tuesday of the Month';
$lang['first_wednesday'] = 'First Wednesday of the Month';
$lang['first_thursday'] = 'First Thursday of the Month';
$lang['first_friday'] = 'First Friday of the Month';
$lang['first_saturday'] = 'First Saturday of the Month';
$lang['second_sunday'] = 'Second Sunday of the Month';
$lang['second_monday'] = 'Second Monday of the Month';
$lang['second_tuesday'] = 'Second Tuesday of the Month';
$lang['second_wednesday'] = 'Second Wednesday of the Month';
$lang['second_thursday'] = 'Second Thursday of the Month';
$lang['second_friday'] = 'Second Friday of the Month';
$lang['second_saturday'] = 'Second Saturday of the Month';
$lang['third_sunday'] = 'Third Sunday of the Month';
$lang['third_monday'] = 'Third Monday of the Month';
$lang['third_tuesday'] = 'Third Tuesday of the Month';
$lang['third_wednesday'] = 'Third Wednesday of the Month';
$lang['third_thursday'] = 'Third Thursday of the Month';
$lang['third_friday'] = 'Third Friday of the Month';
$lang['third_saturday'] = 'Third Saturday of the Month';
$lang['fourth_sunday'] = 'Fourth Sunday of the Month';
$lang['fourth_monday'] = 'Fourth Monday of the Month';
$lang['fourth_tuesday'] = 'Fourth Tuesday of the Month';
$lang['fourth_wednesday'] = 'Fourth Wednesday of the Month';
$lang['fourth_thursday'] = 'Fourth Thursday of the Month';
$lang['fourth_friday'] = 'Fourth Friday of the Month';
$lang['fourth_saturday'] = 'Fourth Saturday of the Month';
$lang['last_sunday'] = 'Last Sunday of the Month';
$lang['last_monday'] = 'Last Monday of the Month';
$lang['last_tuesday'] = 'Last Tuesday of the Month';
$lang['last_wednesday'] = 'Last Wednesday of the Month';
$lang['last_thursday'] = 'Last Thursday of the Month';
$lang['last_friday'] = 'Last Friday of the Month';
$lang['last_saturday'] = 'Last Saturday of the Month';
$lang['error_invalid_recur_monthly_freq'] = 'Invalid frequency.... you cannot specify both the specified date AND other values';
$lang['searchresulttemplate_addedit'] = 'Add/Edit a Search Result Template';
$lang['info_searchresult_template_tab'] = 'The list of templates that are available for the search results display';
$lang['info_sysdflt_searchresult_template'] = 'System Default Search Result Template';
$lang['cal_search_result_templates'] = 'Search Result Templates';
$lang['error_query_failed'] = 'Database Query Failed';
$lang['error_search_invalid_dates'] = 'Invalid Search Dates Specified';
$lang['text'] = 'Text';
$lang['search'] = 'Search';
$lang['category'] = 'Category';
$lang['info_sysdflt_search_template'] = 'System Default Search Form Template';
$lang['searchtemplate_addedit'] = 'Add/Edit a Search Form Template';
$lang['info_search_template_tab'] = 'The list of templates that are available for the search form';
$lang['cal_search_form_templates'] = 'Search Form Templates';
$lang['max'] = 'maks';
$lang['times'] = 'gange';
$lang['on'] = 'til';
$lang['areyousure_uninstall'] = 'Er du sikker p&aring; du vil g&oslash;re dette? Hvis du forts&aelig;tter slettes alle data tilknyttet dette modul permanent.';
$lang['post_uninstall'] = 'The Calendar module has been uninstalled and all event and template information associated with this module has been removed';
$lang['fieldupdated'] = 'Felt opdateret';
$lang['every'] = 'Hver';
$lang['or'] = 'eller';
$lang['update_children'] = 'Opdat&eacute;r under-h&aelig;ndelser';
$lang['error_nocategory'] = 'Du skal v&aelig;lge mindst en kategori';
$lang['error_nothingselected'] = 'Der er ikke valgt noget til sletning';
$lang['error_eventoverlap'] = 'Den gentagende h&aelig;ndelse du har angivet ville resultere i overlappende h&aelig;ndelser.';
$lang['recurs'] = 'Gentages';
$lang['error_invalid_dates'] = 'En eller flere at de angivne datoer er ugyldig';
$lang['sunday'] = 'S&oslash;ndag';
$lang['monday'] = 'Mandag';
$lang['tuesday'] = 'Tirsdag';
$lang['wednesday'] = 'Onsdag';
$lang['thursday'] = 'Torsdag';
$lang['friday'] = 'Fredag';
$lang['saturday'] = 'L&oslash;rdag';
$lang['abbr_sunday'] = 'S&oslash;n';
$lang['abbr_monday'] = 'Man';
$lang['abbr_tuesday'] = 'Tir';
$lang['abbr_wednesday'] = 'Ons';
$lang['abbr_thursday'] = 'Tor';
$lang['abbr_friday'] = 'Fre';
$lang['abbr_saturday'] = 'L&oslash;r';
$lang['weekdays'] = 'Ugedage';
$lang['plural_daily'] = 'Dage';
$lang['plural_weekly'] = 'Uger';
$lang['plural_monthly'] = 'M&aring;neder';
$lang['plural_yearly'] = '&Aring;r';
$lang['no'] = 'Nej';
$lang['daily'] = 'Dagligt';
$lang['weekly'] = 'Ugentligt';
$lang['monthly'] = 'M&aring;nedligt';
$lang['yearly'] = '&Aring;rligt';
$lang['interval'] = 'Gentag hver';
$lang['cal_recur_details'] = 'Detaljer om tilbagevendende h&aelig;ndelse';
$lang['unlimited'] = 'Ubegr&aelig;nset';
$lang['max_recur_events'] = 'Maksimalt antal under h&aelig;ndelser';
$lang['use_to_date'] = 'Angiv en alternativ slut dato?';
$lang['cancel'] = 'Afbryd';
$lang['show_child_events'] = 'Vis under-h&aelig;ndelser <em>(kan medf&oslash;re meget lang visning)</em>';
$lang['n/a'] = 'n/a';
$lang['recurs_until'] = 'Gentag indtil';
$lang['parent'] = 'Overh&aelig;ndelser';
$lang['recur_period'] = 'Gentagelsesperiode';
$lang['filter'] = 'Filter';
$lang['start_date'] = 'Start dato';
$lang['end_date'] = 'Slut dato';
$lang['info_upcominglist_template_tab'] = 'The list of templates that are available for upcominglist views';
$lang['upcominglisttemplate_addedit'] = 'Add/Edit an Upcominglist Display Template';
$lang['info_sysdflt_upcominglist_template'] = 'System Default Upcominglist Template';
$lang['info_list_template_tab'] = 'The list of templates that are available for list views';
$lang['listtemplate_addedit'] = 'Add/Edit an List Display Template';
$lang['info_sysdflt_list_template'] = 'System Default List Template';
$lang['info_event_template_tab'] = 'The list of templates that are available for event views';
$lang['eventtemplate_addedit'] = 'Add/Edit an Event Display Template';
$lang['info_sysdflt_event_template'] = 'System Default Event Template';
$lang['info_calendar_template_tab'] = 'The list of templates that are available for calendar views';
$lang['calendartemplate_addedit'] = 'Add/Edit a Calendar Display Template';
$lang['info_sysdflt_calendar_template'] = 'System Default Calendar Template';
$lang['info_sysdflt_template'] = 'This form defines the template that will be used when you click &quot;New Template&quot; in the appropriate tab.  Changing this value will have no immediate effect on the displays generated from this module.';
$lang['eventdesc-EventAdded'] = 'Kaldes efter en h&aelig;ndelse er tilf&oslash;jet';
$lang['eventdesc-EventEdited'] = 'Kaldes efter en h&aelig;ndelse er blevet &aelig;ndret';
$lang['eventdesc-EventDeleted'] = 'Kaldes efter en h&aelig;ndelse er blevet slettet';
$lang['eventdesc-CategoryAdded'] = 'Kaldes efter en kategori er oprettet';
$lang['eventdesc-CategoryEdited'] = 'Kaldes efter en kategori er blevet redigeret';
$lang['eventdesc-CategoryDeleted'] = 'Kaldes efter en kategori er blevet slettet';
$lang['eventhelp-EventAdded'] = '<p>Sent when a calendar event is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_title\&quot; - Event Title</li>
<li>\&quot;event_summary\&quot; - Summary Text</li>
<li>\&quot;event_details\&quot; - Detailed Description</li>
<li>\&quot;event_date_start\&quot; - The event start date/time</li>
<li>\&quot;event_date_end\&quot; - The event end date/time</li>
<li>\&quot;event_created_by\&quot; - The userid of the author</li>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-EventEdited'] = '<p>Sent when a calendar event is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_title\&quot; - Event Title</li>
<li>\&quot;event_summary\&quot; - Summary Text</li>
<li>\&quot;event_details\&quot; - Detailed Description</li>
<li>\&quot;event_date_start\&quot; - The event start date/time</li>
<li>\&quot;event_date_end\&quot; - The event end date/time</li>
<li>\&quot;event_created_by\&quot; - The userid of the author</li>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-EventDeleted'] = '<p>Sent when a calendar event is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;event_id\&quot; - The event id</li>
</ul>
';
$lang['eventhelp-CategoryAdded'] = '<p>Sent when a calendar category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
</ul>
';
$lang['eventhelp-CategoryEdited'] = '<p>Sent when a calendar category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
<li>\&quot;category_name\&quot; - The category name</li>
<li>\&quot;category_order\&quot; - The category sort order</li>
</ul>
';
$lang['eventhelp-CategoryDeleted'] = '<p>Sent when a calendar category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - The category id</li>
<li>\&quot;category_name\&quot; - The category name</li>
<li>\&quot;category_order\&quot; - The category sort order</li>
</ul>
';
$lang['msg_eventadded'] = 'H&aelig;ndelse tilf&oslash;jet';
$lang['error_noeventname'] = 'H&aelig;ndelsen skal have et navn';
$lang['error_noupload'] = 'ERROR: No uploaded file found';
$lang['error_invalidfilename'] = 'ERROR: The file uploaded cannot be accepted';
$lang['error_problemwithupload'] = 'ERROR: A problem occurred trying to upload the file';
$lang['error_filecopyfailed'] = 'ERROR: A Problem occurred when copying the file to its final destination';
$lang['error_fileexists'] = 'ERROR: A file by that name already exists';
$lang['error_csvfilenotfound'] = 'Fejl: kunne ikke finde CSV-filen';
$lang['error_cantopenfile'] = 'Fejl: kan ikke &aring;bne filen';
$lang['error_categoryexists'] = 'ERROR: A category with the name %s already exists';
$lang['cal_id'] = 'Id';
$lang['cal_calendar'] = 'Kalender';
$lang['cal_default_templates'] = 'Standard skabeloner';
$lang['cal_description'] = 'Tilf&oslash;j, ret og slet h&aelig;ndelser';
$lang['cal_addevent'] = 'Tilf&oslash;j h&aelig;ndelse';
$lang['cal_import_events'] = 'Import&eacute;r h&aelig;ndelser';
$lang['cal_events'] = 'H&aelig;ndelser';
$lang['cal_categories'] = 'Kategorier';
$lang['cal_calendar_template'] = 'Kalender skabelon';
$lang['cal_list_template'] = 'Liste skabelon';
$lang['cal_upcominglist_template'] = 'Skabelon for kommende h&aelig;ndelser';
$lang['cal_event_template'] = 'Skabelon for h&aelig;ndelse';
$lang['cal_settings'] = 'Indstillinger';
$lang['cal_prev'] = '&laquo; Forrige';
$lang['cal_next'] = 'N&aelig;ste &raquo;';
$lang['cal_categories_updated'] = 'Kategorier opdateret';
$lang['cal_settings_updated'] = 'Indstillinger opdateret';
$lang['cal_add_event'] = 'Tilf&oslash;j h&aelig;ndelse';
$lang['cal_edit'] = 'Ret';
$lang['cal_delete'] = 'Slet';
$lang['cal_areyousure'] = 'Er du sikker p&aring; du vil slette';
$lang['cal_update_template'] = 'Opdat&eacute;r skabelon';
$lang['cal_sunday'] = 'S&oslash;ndag';
$lang['cal_monday'] = 'Mandag';
$lang['cal_tuesday'] = 'Tirsdag';
$lang['cal_wednesday'] = 'Onsdag';
$lang['cal_thursday'] = 'Torsdag';
$lang['cal_friday'] = 'Fredag';
$lang['cal_saturday'] = 'L&oslash;rdag';
$lang['cal_sun'] = 'S&oslash;n';
$lang['cal_mon'] = 'Man';
$lang['cal_tues'] = 'Tir';
$lang['cal_wed'] = 'Ons';
$lang['cal_thurs'] = 'Tor';
$lang['cal_fri'] = 'Fre';
$lang['cal_sat'] = 'L&oslash;r';
$lang['cal_january'] = 'Januar';
$lang['cal_february'] = 'Februar';
$lang['cal_march'] = 'Marts';
$lang['cal_april'] = 'April';
$lang['cal_may'] = 'Maj';
$lang['cal_june'] = 'Juni';
$lang['cal_july'] = 'Juli';
$lang['cal_august'] = 'August';
$lang['cal_september'] = 'September';
$lang['cal_october'] = 'Oktober';
$lang['cal_november'] = 'November';
$lang['cal_december'] = 'December';
$lang['cal_add'] = 'Opdat&eacute;r';
$lang['cal_update'] = 'Tilf&oslash;j';
$lang['cal_event'] = 'H&aelig;ndelse';
$lang['cal_date'] = 'Dato';
$lang['cal_summary'] = 'Oversigt';
$lang['cal_details'] = 'Detaljer';
$lang['cal_more'] = 'mere >>';
$lang['cal_return'] = 'Tilbage';
$lang['cal_to'] = 'til';
$lang['cal_past_events'] = 'Overst&aring;ede h&aelig;ndelser';
$lang['cal_upcoming_events'] = 'Kommende h&aelig;ndelser';
$lang['cal_any_category'] = 'Alle kategorier';
$lang['cal_show_only_events_in'] = 'Vis kun h&aelig;ndelser i';
$lang['cal_filter_by'] = 'Filtr&eacute;r p&aring;';
$lang['cal_go'] = 'K&oslash;r';
$lang['cal_title'] = 'Titel';
$lang['cal_fromdate'] = 'Fra dato';
$lang['cal_todate'] = 'Til dato';
$lang['cal_update_categories'] = 'Opdat&eacute;r kategorier';
$lang['cal_language'] = 'Sprog';
$lang['cal_updatesettings'] = 'Opdat&eacute;r indstillinger';
$lang['cal_use_twelve_hour_clock'] = 'Benyt 12-tidsangivelse i dropdown.';
$lang['cal_default_category'] = 'Standard kategori';
$lang['cal_update_fields'] = 'Opdater felter';
$lang['force_category'] = 'P&aring;tving mindst en kategori';
$lang['showpastyears'] = 'Hvor mange &aring;r tilbage i tiden der kan angives';
$lang['showfutureyears'] = 'Hvor mange &aring;r ud i fremtiden der kan angives';
$lang['hidesummary'] = 'Skal resume feltet skjules';
$lang['hidecontent'] = 'Skal indholdsfeltet skjules';
$lang['category_reminder'] = 'Angiv mindst en kategori for denne h&aelig;ndelse';
$lang['module_example_stylesheet'] = 'Kalender CSS eksempel';
$lang['error_permission'] = 'Du skal have den n&oslash;dvendige tilladelse (%s) for at kunne benytte den funktion';
$lang['install_postmessage'] = 'Husk at sl&aring; tilladelsen &quot;Modify Calendar&quot; til for brugere der skal kunne administrere kalenderen.';
$lang['deletetagged'] = 'Slet markerede h&aelig;ndelser';
$lang['confirmdeletetagged'] = 'Er du sikker p&aring; disse h&aelig;ndelser skal slettes?';
$lang['taggeddeleted'] = 'Markerede h&aelig;ndelser blev slettet';
$lang['templates'] = 'Skabeloner';
$lang['template_help'] = 'Skabelon hj&aelig;lp';
$lang['file_templates'] = 'Fil-skabeloner';
$lang['addtemplate'] = 'Tilf&oslash;j skabelon';
$lang['template'] = 'Skabelon';
$lang['templatenametext'] = 'Skabelon navn';
$lang['edittemplate'] = 'Redig&eacute;r skabelon';
$lang['deletetemplate'] = 'Slet skabelon';
$lang['newtemplate'] = 'Nyt skabelon navn';
$lang['templatenameexists'] = 'Fejl: En skabelon med det navn eksisterer allerede';
$lang['templateimported'] = 'Skabelonen blev importeret i databasen og er nu klar til brug.';
$lang['view_default_stylesheet'] = 'Vis standard stylesheet';
$lang['filename'] = 'Filnavn';
$lang['importtemplate'] = 'Import&eacute;r skabelon';
$lang['template_deleted'] = 'Skabelonen blev slettet fra databasen';
$lang['updatetemplatesuccess'] = 'Skabelonen blev opdateret';
$lang['updatetemplatefailure'] = 'Der skete en fejl ved opdatering';
$lang['settingssaved'] = 'Indstillingerne blev gemt';
$lang['categorydeleted'] = 'Kategorien blev slettet';
$lang['categoryupdated'] = 'Kategorien blev opdateret';
$lang['categoryadded'] = 'Kategorien blev tilf&oslash;jet';
$lang['eventdeleted'] = 'H&aelig;ndelsen blev slettet';
$lang['eventupdated'] = 'H&aelig;ndelse blev opdateret';
$lang['default_page_error'] = 'Fejl: Du skal angive en standardside hvis du vil benytte kalenderen med pretty URL&#039;s sl&aring;et til. G&aring; venligst til kalender indstillingerne og v&aelig;lg en.';
$lang['time_at'] = 'kl.';
$lang['type'] = 'Type';
$lang['name'] = 'Navn';
$lang['order'] = 'R&aelig;kkef&oslash;lge';
$lang['fieldadded'] = 'Feltet blev tilf&oslash;jet';
$lang['fielddeleted'] = 'Feltet slettet';
$lang['fields'] = 'Brugerdefinerede felter';
$lang['textfield'] = 'Tekst felt';
$lang['uploadfield'] = 'Fil-upload felt';
$lang['description'] = '<p>Kalender modulet bruges til at vise begivenheder p&aring; din side. N&aring;r modulet er installeret bliver der tilf&oslash;jet en kalende admin side til indholdsmenuen, der vil lade dig styre dine begivenheder.</p>';
$lang['defaultcalendarpage'] = 'Siden, der som standard indeholder Kalenderen. Denne side skal indeholde en Smarty tag der kalder Kalender. N&oslash;dvendig hvis du &oslash;nsker at benytte &quot;pretty URLs&quot;';
$lang['uploaddirectory'] = 'Directory wherer file uploads should be placed';
$lang['uploadfiletypes'] = 'Tilladte filtyper';
$lang['uploadunique'] = 'Tving unikke filnavne';
$lang['thumb_width'] = 'Thumbnail bredde';
$lang['thumb_height'] = 'Thumbnail h&oslash;jde';
$lang['large_width'] = 'Stort billede bredde';
$lang['large_height'] = 'Stort billede h&oslash;jde';
$lang['cal_recur_period'] = 'Gentages';
$lang['cal_recur_until'] = 'Gentages indtil';
$lang['help_template'] = '<p><b>Print Author Name:</b></p>
<code>Author: {$event.authorname}</code>
';
?>
